@@ -67,7 +67,7 @@ class BaseAPI(object):
 
         url = urlparse.urljoin(self.end_point, url)
 
-        # lookup table to find out the apropriate requests method,
+        # lookup table to find out the appropriate requests method,
         # headers and payload type (json or query parameters)
         identity = lambda x: x
         json_dumps = lambda x: json.dumps(x)
@@ -106,7 +106,6 @@ class BaseAPI(object):
         all_data = data
         while data.get("links", {}).get("pages", {}).get("next"):
             url, query = data["links"]["pages"]["next"].split("?", 1)
-            print(params)
 
             # Merge the query parameters
             for key, value in urlparse.parse_qs(query).items():
@@ -123,6 +122,14 @@ class BaseAPI(object):
 
         return all_data
 
+    def __init_ratelimit(self, headers):
+        # Add the account requests/hour limit
+        self.ratelimit_limit = headers.get('Ratelimit-Limit', None)
+        # Add the account requests remaining
+        self.ratelimit_remaining = headers.get('Ratelimit-Remaining', None)
+        # Add the account requests limit reset time
+        self.ratelimit_reset = headers.get('Ratelimit-Reset', None)
+
     def get_timeout(self):
         """
             Checks if any timeout for the requests to DigitalOcean is required.
@@ -172,7 +179,10 @@ class BaseAPI(object):
             msg = [data[m] for m in ("id", "message") if m in data][1]
             raise DataReadError(msg)
 
-        # If there are more elements available (total) than the elements per 
+        # init request limits
+        self.__init_ratelimit(req.headers)
+
+        # If there are more elements available (total) than the elements per
         # page, try to deal with pagination. Note: Breaking the logic on
         # multiple pages,
         pages = data.get("links", {}).get("pages", {})
