@@ -10,6 +10,9 @@ class TestManager(BaseTest):
     def setUp(self):
         super(TestManager, self).setUp()
         self.manager = digitalocean.Manager(token=self.token)
+        self.image = digitalocean.Image(
+            id=449676856, slug='testslug', token=self.token
+        )
 
     @responses.activate
     def test_get_account(self):
@@ -102,7 +105,6 @@ class TestManager(BaseTest):
                       status=200,
                       content_type="application/json")
 
-
         manager = digitalocean.Manager(token=self.token)
         droplets = manager.get_all_droplets(tag_name="awesome")
 
@@ -148,7 +150,7 @@ class TestManager(BaseTest):
         self.assertEqual(region.token, self.token)
         self.assertEqual(region.name, 'New York')
         self.assertEqual(region.slug, 'nyc1')
-        self.assertEqual(region.sizes,["1gb", "512mb"])
+        self.assertEqual(region.sizes, ["1gb", "512mb"])
         self.assertEqual(region.features, ['virtio',
                                            'private_networking',
                                            'backups',
@@ -177,6 +179,43 @@ class TestManager(BaseTest):
         self.assertEqual(size.transfer, 1)
         self.assertEqual(size.regions, ["nyc1", "ams1", "sfo1"])
 
+    @responses.activate
+    def test_get_image(self):
+        """Test get image by id."""
+        data = self.load_from_file('images/single.json')
+        url = "{}images/{}".format(self.base_url, self.image.id)
+
+        responses.add(responses.GET,
+                      url,
+                      body=data,
+                      status=200,
+                      content_type='application/json')
+
+        self.image.load()
+
+        self.assert_get_url_equal(responses.calls[0].request.url, url)
+        self.assertEqual(self.image.id, 449676856)
+        self.assertEqual(self.image.slug, 'testslug')
+        self.assertEqual(self.image.name, 'My Snapshot')
+
+    @responses.activate
+    def test_get_image_by_slug(self):
+        """Test get image by slug."""
+        data = self.load_from_file('images/single.json')
+        url = "{}images/{}".format(self.base_url, self.image.slug)
+        responses.add(responses.GET,
+                      url,
+                      body=data,
+                      status=200,
+                      content_type='application/json')
+
+        self.image.load(use_slug=True)
+
+        self.assert_get_url_equal(responses.calls[0].request.url, url)
+        self.assertEqual(self.image.id, 449676856)
+        self.assertEqual(self.image.slug, 'testslug')
+        self.assertEqual(self.image.name, 'My Snapshot')
+
     @responses.activate
     def test_get_all_images(self):
         data = self.load_from_file('images/all.json')
@@ -246,8 +285,10 @@ class TestManager(BaseTest):
         self.assertEqual(image.distribution, 'Ubuntu')
         self.assertEqual(image.regions, ['nyc1', 'nyc3'])
         self.assertEqual(image.created_at, "2014-08-18T16:35:40Z")
-        self.assert_url_query_equal(responses.calls[0].request.url,
-                                    'https://api.digitalocean.com/v2/images/?private=true&per_page=200')
+        self.assert_url_query_equal(
+            responses.calls[0].request.url,
+            'https://api.digitalocean.com/v2/images/?private=true&per_page=200'
+        )
 
     @responses.activate
     def test_get_distro_images(self):
@@ -442,5 +483,121 @@ class TestManager(BaseTest):
         self.assertEqual(volumes[0].id, "506f78a4-e098-11e5-ad9f-000f53306ae1")
         self.assertEqual(volumes[0].region['slug'], 'nyc1')
 
+    @responses.activate
+    def test_get_all_tags(self):
+        data = self.load_from_file('tags/all.json')
+
+        url = self.base_url + 'tags'
+        responses.add(responses.GET, url,
+                      body=data,
+                      status=200,
+                      content_type='application/json')
+
+        all_tags = self.manager.get_all_tags()
+
+        self.assertEqual(len(all_tags), 1)
+        self.assertEqual(all_tags[0].name, 'test')
+        self.assertEqual(all_tags[0].resources['droplets']['count'], 0)
+
+    @responses.activate
+    def test_get_all_snapshots(self):
+        data = self.load_from_file('snapshots/all.json')
+
+        url = self.base_url + 'snapshots/'
+        responses.add(responses.GET, url,
+                      body=data,
+                      status=200,
+                      content_type='application/json')
+
+        all_snapshots = self.manager.get_all_snapshots()
+
+        self.assertEqual(len(all_snapshots), 1)
+        self.assertEqual(all_snapshots[0].name, 'test')
+        self.assertEqual(all_snapshots[0].id, 6372321)
+        self.assertEqual(all_snapshots[0].size_gigabytes, 1.42)
+        self.assertEqual(all_snapshots[0].resource_type, 'droplet')
+        self.assertEqual(len(all_snapshots[0].regions), 11)
+
+    @responses.activate
+    def test_get_droplet_snapshots(self):
+        data = self.load_from_file('snapshots/droplets.json')
+
+        url = self.base_url + 'snapshots?resource_type=droplet&per_page=200'
+        responses.add(responses.GET, url,
+                      match_querystring=True,
+                      body=data,
+                      status=200,
+                      content_type='application/json')
+
+        droplet_snapshots = self.manager.get_droplet_snapshots()
+
+        self.assertEqual(len(droplet_snapshots), 1)
+        self.assertEqual(droplet_snapshots[0].name, 'droplet-test')
+        self.assertEqual(droplet_snapshots[0].id, 19602538)
+        self.assertEqual(droplet_snapshots[0].min_disk_size, 20)
+        self.assertEqual(droplet_snapshots[0].size_gigabytes, 0.31)
+        self.assertEqual(droplet_snapshots[0].resource_type, 'droplet')
+        self.assertEqual(len(droplet_snapshots[0].regions), 12)
+
+    @responses.activate
+    def test_get_volume_snapshots(self):
+        data = self.load_from_file('snapshots/volumes.json')
+
+        url = self.base_url + 'snapshots?resource_type=volume&per_page=200'
+        responses.add(responses.GET, url,
+                      match_querystring=True,
+                      body=data,
+                      status=200,
+                      content_type='application/json')
+
+        volume_snapshots = self.manager.get_volume_snapshots()
+
+        self.assertEqual(len(volume_snapshots), 1)
+        self.assertEqual(volume_snapshots[0].name, 'volume-test')
+        self.assertEqual(
+            volume_snapshots[0].id, '4f60fc64-85d1-11e6-a004-000f53315871'
+        )
+        self.assertEqual(volume_snapshots[0].min_disk_size, 10)
+        self.assertEqual(volume_snapshots[0].size_gigabytes, 0)
+        self.assertEqual(volume_snapshots[0].resource_type, 'volume')
+        self.assertEqual(len(volume_snapshots[0].regions), 1)
+
+    @responses.activate
+    def test_get_firewalls(self):
+        data = self.load_from_file('firewalls/all.json')
+
+        url = self.base_url + "firewalls"
+        responses.add(responses.GET,
+                      url,
+                      body=data,
+                      status=200,
+                      content_type='application/json')
+
+        firewalls = self.manager.get_all_firewalls()
+        f = firewalls[0]
+
+        self.assert_get_url_equal(responses.calls[0].request.url, url)
+        self.assertEqual(f.id, "12345")
+        self.assertEqual(f.name, "firewall")
+        self.assertEqual(f.status, "succeeded")
+        self.assertEqual(f.inbound_rules[0].ports, "80")
+        self.assertEqual(f.inbound_rules[0].protocol, "tcp")
+        self.assertEqual(f.inbound_rules[0].sources.load_balancer_uids,
+                         ["12345"])
+        self.assertEqual(f.inbound_rules[0].sources.addresses, [])
+        self.assertEqual(f.inbound_rules[0].sources.tags, [])
+        self.assertEqual(f.outbound_rules[0].ports, "80")
+        self.assertEqual(f.outbound_rules[0].protocol, "tcp")
+        self.assertEqual(
+            f.outbound_rules[0].destinations.load_balancer_uids, [])
+        self.assertEqual(f.outbound_rules[0].destinations.addresses,
+                         ["0.0.0.0/0", "::/0"])
+        self.assertEqual(f.outbound_rules[0].destinations.tags, [])
+        self.assertEqual(f.created_at, "2017-05-23T21:24:00Z")
+        self.assertEqual(f.droplet_ids, [12345])
+        self.assertEqual(f.tags, [])
+        self.assertEqual(f.pending_changes, [])
+
+
 if __name__ == '__main__':
     unittest.main()
